from earthdiagnostics import Utils, cdftools
from log import Log
from nco import NCOException
import os
import shutil


def moc(input_file, output_file):
    """
    Compute the MOC for oceanic basins
    Created in March 2012
    Author : vguemas@ic3.cat

    :param input_file:  input grid_V file name
    :type input_file: str
    :param output_file: output file name (=> 2D, depth-y)
    :param output_file: str
    :return:
    """
    nco = Utils.nco
    if os.path.exists(output_file):
        os.remove(output_file)

    cdftools.run('cdfmoc', input=input_file, output=output_file)
    nco.ncwa(input=output_file, output=output_file, options='-O -a x')
    nco.ncks(input=output_file, output=output_file, options='-O -x -v nav_lon,nav_lat')

    nco.ncrename(input=output_file, options='-v .time_counter,time -d .time_counter,time')
    nco.ncrename(input=output_file, options='-d .gsize,y')

    temp = Utils.get_temp_file()
    shutil.copy(input_file, temp)
    nco.ncrename(input=output_file, options='-v .time_counter,time -d .time_counter,time')

    nco.ncks(input=input_file, output=output_file, options='-A -v nav_lon,nav_lat')

def main():
    try:
        moc("ORCA1_MM_19601101_19610228_grid_V.nc", "out.nc")
        Utils.clean()
    except NCOException as ex:
        Log.error('Exception {0}: stderr: {1}, stdout: {2}',  ex.msg, ex.stderr, ex.stdout)

if __name__ == "__main__":
    main()